@@ -6,7 +6,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.57
+0.58
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || $ENV{SWAGGER2_DEBUG} || 0;
 use constant WARN_ON_MISSING_FORMAT => $ENV{JSON_VALIDATOR_WARN_ON_MISSING_FORMAT}
   || $ENV{SWAGGER2_WARN_ON_MISSING_FORMAT} ? 1 : 0;
 
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 our @EXPORT_OK = qw( validate_json );
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -930,7 +930,7 @@ sub _guess_data_type {
   return 'object' if $ref eq 'HASH';
   return lc $ref if $ref and !$blessed;
   return 'null' if !defined;
-  return 'boolean' if $blessed and "$_" eq "1" or "$_" eq "0";
+  return 'boolean' if $blessed and ("$_" eq "1" or !"$_");
   return 'number' if B::svref_2object(\$_)->FLAGS & (B::SVp_IOK | B::SVp_NOK) and 0 + $_ eq $_ and $_ * 0 == 0;
   return $blessed || 'string';
 }
